# 更新日志

本文档记录了 CryptoService 项目的所有重要更改和版本发布历史。

## 🎯 版本约定

本项目遵循 [语义化版本控制](https://semver.org/lang/zh-CN/) 规范：

- **主版本号 (MAJOR)**: 当做了不兼容的 API 修改
- **次版本号 (MINOR)**: 当做了向下兼容的功能性新增
- **修订号 (PATCH)**: 当做了向下兼容的问题修正

## 📋 图例

- 🎉 **新功能** - 新增功能特性
- 🐛 **问题修复** - Bug 修复
- 📈 **性能优化** - 性能改进
- 🔧 **开发工具** - 开发环境和工具更新
- 📝 **文档** - 文档更新
- ⚠️ **重大变更** - 破坏性更改
- 🔒 **安全** - 安全修复
- 🗑️ **废弃** - 功能废弃

---

## v1.2.0 (2024-12-26)

### 🎉 新功能

- **WebSocket 实时数据流**: 新增 WebSocketService 支持实时市场数据订阅
  - 支持实时行情、K线数据、深度数据订阅
  - 自动重连和错误恢复机制
  - 事件驱动的数据处理架构

- **高级数据查询**: MarketDB 新增高级查询功能
  - 条件筛选查询 (`read_data_with_conditions`)
  - 百分位数查询 (`read_data_by_percentile`)
  - 时间戳范围导出 (`export_to_files_by_timestamp`)

- **Universe 定义系统**: 完整的 Universe 管理功能
  - 动态交易对选择和重平衡
  - 时间序列快照管理
  - 批量数据下载和存储

### 📈 性能优化

- **并发数据下载**: 多线程下载历史数据，提升效率
- **数据库索引优化**: 为时间戳和交易对字段添加索引
- **内存管理**: 优化大数据集的内存使用

### 📝 文档

- **完整文档重写**: 重新组织和编写所有文档
  - 新增市场数据示例文档
  - 新增数据处理示例文档
  - 新增 WebSocket 服务文档
  - 完善 API 参考文档

### 🔧 开发工具

- **MyPy 类型检查**: 配置 mypy 忽略第三方库类型问题
- **Pre-commit 钩子**: 添加代码格式化和检查
- **MkDocs 文档**: 配置文档生成和预览

---

## v1.1.0 (2024-12-15)

### 🎉 新功能

- **数据存储系统**: 基于 SQLite 的市场数据存储
  - 支持多种频率的 K线数据存储
  - 高效的数据查询和聚合
  - 自动数据去重和验证

- **数据导出功能**: 多格式数据导出
  - CSV 格式导出
  - Parquet 高效压缩格式
  - NumPy 数组格式
  - Excel 多工作表导出

### 🐛 问题修复

- 修复 Binance API 频率限制处理
- 修复时间戳转换问题
- 修复数据类型转换错误

### 📈 性能优化

- 优化数据库查询性能
- 减少不必要的 API 调用
- 改进内存使用效率

---

## v1.0.0 (2024-12-01)

### 🎉 首次发布

- **核心市场数据服务**: MarketDataService
  - 实时行情数据获取
  - 历史 K线数据下载
  - 24小时统计数据
  - 交易所信息查询

- **数据模型**: 完整的数据类型定义
  - BaseMarketTicker 行情数据模型
  - HistoricalKlines K线数据模型
  - Freq 频率枚举
  - SortBy 排序枚举

- **基础工具**:
  - 数据转换工具
  - 异常处理系统
  - 配置管理

### 🔧 开发环境

- Python 3.8+ 支持
- uv 包管理器集成
- ruff 代码格式化和检查
- pytest 测试框架

---

## 🚀 即将推出 (Roadmap)

### v1.3.0 (计划中)

- **智能交易信号**: 技术指标计算和交易信号生成
- **回测系统**: 历史数据回测框架
- **风险管理**: 风险指标计算和监控
- **多交易所支持**: 扩展到其他加密货币交易所

### v1.4.0 (计划中)

- **机器学习集成**: 价格预测和异常检测
- **图形化界面**: Web 界面和仪表板
- **API 网关**: RESTful API 服务
- **云部署**: Docker 和 Kubernetes 支持

### v2.0.0 (长期规划)

- **分布式架构**: 微服务化重构
- **实时流处理**: Apache Kafka 集成
- **大数据存储**: ClickHouse/TimescaleDB 支持
- **企业级功能**: 用户管理、权限控制、审计日志

---

## 📊 版本统计

| 版本 | 发布日期 | 新功能 | 问题修复 | 文档更新 |
|------|----------|--------|----------|----------|
| v1.2.0 | 2024-12-26 | 5 | 2 | 4 |
| v1.1.0 | 2024-12-15 | 3 | 3 | 1 |
| v1.0.0 | 2024-12-01 | 8 | 0 | 3 |
| **总计** | | **16** | **5** | **8** |

---

## 📞 反馈和贡献

如果您发现任何问题或有功能建议，请通过以下方式联系我们：

- **GitHub Issues**: [提交问题](https://github.com/username/cryptoservice/issues)
- **功能请求**: [请求新功能](https://github.com/username/cryptoservice/issues/new?template=feature_request.md)
- **贡献代码**: 查看 [贡献指南](contributing.md)

---

## 🙏 致谢

感谢所有为 CryptoService 项目做出贡献的开发者和用户！

### 主要贡献者

- **[@Mrzai](https://github.com/Mrzai)** - 项目创始人和主要维护者
- **社区贡献者** - 感谢所有提供反馈和建议的用户

### 依赖项目

本项目基于以下优秀的开源项目构建：

- [python-binance](https://github.com/sammchardy/python-binance) - Binance API 客户端
- [pandas](https://pandas.pydata.org/) - 数据分析库
- [SQLite](https://www.sqlite.org/) - 轻量级数据库
- [pytest](https://pytest.org/) - 测试框架
- [ruff](https://github.com/astral-sh/ruff) - 代码检查工具

---

💡 **提示**: 订阅我们的 [发布通知](https://github.com/username/cryptoservice/releases) 以获取最新版本信息。
